aboutsummaryrefslogtreecommitdiff
path: root/test/functional/wallet_basic.py
diff options
context:
space:
mode:
authorJon Atack <jon@atack.com>2019-09-14 19:48:38 +0200
committerJon Atack <jon@atack.com>2019-09-14 20:17:19 +0200
commit0f34f54888f680bfbe7a29ac278636d7178a99bb (patch)
tree220005265c9f1dfe46cef7d60b7cf0695b001ee6 /test/functional/wallet_basic.py
parent4bfef0daeb9351c200b5bd09e60596a29b4d3523 (diff)
downloadbitcoin-0f34f54888f680bfbe7a29ac278636d7178a99bb.tar.xz
rpc: fix regression in gettransaction
PR 16866 renamed the 'decode' argument in gettransaction to 'verbose' to make it more consistent with other RPC calls like getrawtransaction. However, it seems it inadvertently overloaded the 'details' fields when 'verbose' is passed. The result is that the original 'details' fields are no longer returned, which seems to be a breaking API change. This PR takes the simplest path to restoring the 'details' fields by renaming them from 'details' back to 'decoded', while leaving the 'verbose' argument for API consistency. It also addresses [this comment](https://github.com/bitcoin/bitcoin/pull/16185#discussion_r320740413) to mention that the 'decoded' field is identical to decoderawtransaction. Update the RPC help, functional test, and release note.
Diffstat (limited to 'test/functional/wallet_basic.py')
-rwxr-xr-xtest/functional/wallet_basic.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/functional/wallet_basic.py b/test/functional/wallet_basic.py
index 4c3fe3078b..40ad9081ae 100755
--- a/test/functional/wallet_basic.py
+++ b/test/functional/wallet_basic.py
@@ -499,10 +499,10 @@ class WalletTest(BitcoinTestFramework):
self.nodes[0].setlabel(change, 'foobar')
assert_equal(self.nodes[0].getaddressinfo(change)['ischange'], False)
# Test "verbose" field value in gettransaction response
self.log.info("Testing verbose gettransaction...")
tx = self.nodes[0].gettransaction(txid=txid, verbose=True)
- assert_equal(tx["details"], self.nodes[0].decoderawtransaction(tx["hex"]))
+ assert_equal(tx["decoded"], self.nodes[0].decoderawtransaction(tx["hex"]))
if __name__ == '__main__':
@@ -499,10 +499,10 @@ class WalletTest(BitcoinTestFramework):
self.nodes[0].setlabel(change, 'foobar')
assert_equal(self.nodes[0].getaddressinfo(change)['ischange'], False)
- # Test "verbose" field value in gettransaction response
+ # Test "decoded" field value in gettransaction `verbose` response.
self.log.info("Testing verbose gettransaction...")
tx = self.nodes[0].gettransaction(txid=txid, verbose=True)